==> blancoNLpackGenerator-0.0.88a-src.zip: src/blanco/xliff/valueobject/BlancoXliffTarget.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

/**
 * OASIS XLIFF  target 킷o[IuWFNgB
 */
public class BlancoXliffTarget {
    /**
     * tB[h [state]
     *
     * ڂ̌^ [java.lang.String]<br>
     * stateB|󋵁B
     */
    private String fState;

    /**
     * tB[h [state-qualifier]
     *
     * ڂ̌^ [java.lang.String]<br>
     * state-qualifierB|󋵂̏ڍׁB
     */
    private String fStateQualifier;

    /**
     * tB[h [target]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |㕶B
     */
    private String fTarget;

    /**
     * tB[h [state]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * stateB|󋵁B
     *
     * @param argState tB[h[state]Ɋi[l
     */
    public void setState(final String argState) {
        fState = argState;
    }

    /**
     * tB[h[state]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * stateB|󋵁B
     *
     * @return tB[h[state]Ɋi[Ăl
     */
    public String getState() {
        return fState;
    }

    /**
     * tB[h [state-qualifier]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * state-qualifierB|󋵂̏ڍׁB
     *
     * @param argStateQualifier tB[h[state-qualifier]Ɋi[l
     */
    public void setStateQualifier(final String argStateQualifier) {
        fStateQualifier = argStateQualifier;
    }

    /**
     * tB[h[state-qualifier]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * state-qualifierB|󋵂̏ڍׁB
     *
     * @return tB[h[state-qualifier]Ɋi[Ăl
     */
    public String getStateQualifier() {
        return fStateQualifier;
    }

    /**
     * tB[h [target]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |㕶B
     *
     * @param argTarget tB[h[target]Ɋi[l
     */
    public void setTarget(final String argTarget) {
        fTarget = argTarget;
    }

    /**
     * tB[h[target]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |㕶B
     *
     * @return tB[h[target]Ɋi[Ăl
     */
    public String getTarget() {
        return fTarget;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliffTarget[");
        buf.append("state=" + fState);
        buf.append(",state-qualifier=" + fStateQualifier);
        buf.append(",target=" + fTarget);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.1.20-src.zip: src/blanco/xliff/valueobject/BlancoXliffTarget.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.xliff.valueobject;

/**
 * OASIS XLIFF  target 킷o[IuWFNgB
 */
public class BlancoXliffTarget {
    /**
     * tB[h [state]
     *
     * ڂ̌^ [java.lang.String]<br>
     * stateB|󋵁B
     */
    private String fState;

    /**
     * tB[h [state-qualifier]
     *
     * ڂ̌^ [java.lang.String]<br>
     * state-qualifierB|󋵂̏ڍׁB
     */
    private String fStateQualifier;

    /**
     * tB[h [target]
     *
     * ڂ̌^ [java.lang.String]<br>
     * |㕶B
     */
    private String fTarget;

    /**
     * tB[h [phase-name]
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     */
    private String fPhaseName;

    /**
     * tB[h [state]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * stateB|󋵁B
     *
     * @param argState tB[h[state]Ɋi[l
     */
    public void setState(final String argState) {
        fState = argState;
    }

    /**
     * tB[h[state]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * stateB|󋵁B
     *
     * @return tB[h[state]Ɋi[Ăl
     */
    public String getState() {
        return fState;
    }

    /**
     * tB[h [state-qualifier]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * state-qualifierB|󋵂̏ڍׁB
     *
     * @param argStateQualifier tB[h[state-qualifier]Ɋi[l
     */
    public void setStateQualifier(final String argStateQualifier) {
        fStateQualifier = argStateQualifier;
    }

    /**
     * tB[h[state-qualifier]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * state-qualifierB|󋵂̏ڍׁB
     *
     * @return tB[h[state-qualifier]Ɋi[Ăl
     */
    public String getStateQualifier() {
        return fStateQualifier;
    }

    /**
     * tB[h [target]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |㕶B
     *
     * @param argTarget tB[h[target]Ɋi[l
     */
    public void setTarget(final String argTarget) {
        fTarget = argTarget;
    }

    /**
     * tB[h[target]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * |㕶B
     *
     * @return tB[h[target]Ɋi[Ăl
     */
    public String getTarget() {
        return fTarget;
    }

    /**
     * tB[h [phase-name]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @param argPhaseName tB[h[phase-name]Ɋi[l
     */
    public void setPhaseName(final String argPhaseName) {
        fPhaseName = argPhaseName;
    }

    /**
     * tB[h[phase-name]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * tF[YB
     *
     * @return tB[h[phase-name]Ɋi[Ăl
     */
    public String getPhaseName() {
        return fPhaseName;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.xliff.valueobject.BlancoXliffTarget[");
        buf.append("state=" + fState);
        buf.append(",state-qualifier=" + fStateQualifier);
        buf.append(",target=" + fTarget);
        buf.append(",phase-name=" + fPhaseName);
        buf.append("]");
        return buf.toString();
    }
}
